@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -147,7 +147,7 @@ BatchAssociateScramSecretRequestRequestTypeDef = TypedDict(
     "BatchAssociateScramSecretRequestRequestTypeDef",
     {
         "ClusterArn": str,
-        "SecretArnList": List[str],
+        "SecretArnList": Sequence[str],
     },
 )
 
@@ -164,7 +164,7 @@ BatchDisassociateScramSecretRequestRequestTypeDef = TypedDict(
     "BatchDisassociateScramSecretRequestRequestTypeDef",
     {
         "ClusterArn": str,
-        "SecretArnList": List[str],
+        "SecretArnList": Sequence[str],
     },
 )
 
@@ -198,7 +198,7 @@ BrokerLogsTypeDef = TypedDict(
 _RequiredBrokerNodeGroupInfoTypeDef = TypedDict(
     "_RequiredBrokerNodeGroupInfoTypeDef",
     {
-        "ClientSubnets": List[str],
+        "ClientSubnets": Sequence[str],
         "InstanceType": str,
     },
 )
@@ -206,7 +206,7 @@ _OptionalBrokerNodeGroupInfoTypeDef = TypedDict(
     "_OptionalBrokerNodeGroupInfoTypeDef",
     {
         "BrokerAZDistribution": Literal["DEFAULT"],
-        "SecurityGroups": List[str],
+        "SecurityGroups": Sequence[str],
         "StorageInfo": "StorageInfoTypeDef",
     },
     total=False,
@@ -401,7 +401,7 @@ _OptionalCreateClusterRequestRequestTypeDef = TypedDict(
         "EnhancedMonitoring": EnhancedMonitoringType,
         "OpenMonitoring": "OpenMonitoringInfoTypeDef",
         "LoggingInfo": "LoggingInfoTypeDef",
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -434,7 +434,7 @@ _OptionalCreateConfigurationRequestRequestTypeDef = TypedDict(
     "_OptionalCreateConfigurationRequestRequestTypeDef",
     {
         "Description": str,
-        "KafkaVersions": List[str],
+        "KafkaVersions": Sequence[str],
     },
     total=False,
 )
@@ -994,7 +994,7 @@ PrometheusTypeDef = TypedDict(
 RebootBrokerRequestRequestTypeDef = TypedDict(
     "RebootBrokerRequestRequestTypeDef",
     {
-        "BrokerIds": List[str],
+        "BrokerIds": Sequence[str],
         "ClusterArn": str,
     },
 )
@@ -1077,14 +1077,14 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
 )
 
 TlsTypeDef = TypedDict(
     "TlsTypeDef",
     {
-        "CertificateAuthorityArnList": List[str],
+        "CertificateAuthorityArnList": Sequence[str],
         "Enabled": bool,
     },
     total=False,
@@ -1112,7 +1112,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1139,7 +1139,7 @@ UpdateBrokerStorageRequestRequestTypeDef = TypedDict(
     {
         "ClusterArn": str,
         "CurrentVersion": str,
-        "TargetBrokerEBSVolumeInfo": List["BrokerEBSVolumeInfoTypeDef"],
+        "TargetBrokerEBSVolumeInfo": Sequence["BrokerEBSVolumeInfoTypeDef"],
     },
 )
 
